====================================================
**Neurophysiological Data Analysis with NeuroKit2**
====================================================



.. important::

    Like the software? Don't forget to support it by `starring <https://github.com/neuropsychology/NeuroKit>`_ |:star:|, sponsoring |:revolving_hearts:|, or spreading the word |:love_letter:|

    And don't forget, we don't want NeuroKit2 to become a stale, static and outdated software. We
    count on you to help us making it better by **contributing even the tiniest improvements**
    (a typo, a rephrasing to make things clearer, a comment to the code, a new option, etc.).
    **NeuroKit2 belongs to you.** Make yourself part of the team!

Home
====


Welcome to **NeuroKit**'s documentation, where you can find information and learn about Python, NeuroKit, Physiological Signals and more.

.. seealso::

   You can information on how to cite this documentation `here <https://neuropsychology.github.io/NeuroKit/cite_us.html>`_.


You can navigate to the different sections using the left panel. We recommend checking out the **guides** and **examples**, where you can find tutorials and hands-on walkthroughs.

.. toctree::
   :maxdepth: 1
   :caption: Menu
   :titlesonly:

   introduction
   installation
   authors
   cite_us
   examples/index
   functions/index
   resources/index
   studies/index
   Repository <https://github.com/neuropsychology/NeuroKit>


.. include::  ../README.rst
    :start-after: .. used_at_section

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
